﻿using Styx;
using Styx.Common;
using Styx.Common.Helpers;
using Styx.MemoryManagement;
using Styx.Plugins;
using Styx.WoWInternals;
using Styx.WoWInternals.WoWObjects;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Media;
using System.Text;
using System.Threading.Tasks;

namespace OnyxEggsDetector
{
    public class OnyxEggsDetector : HBPlugin
    {
        private ArrayList sentEggs = new ArrayList();

        public override string Author
        {
            get { return "jim87"; }
        }

        public override string Name
        {
            get { return "Jim87's Onyx Eggs Detector & Navigator"; }
        }

        public override Version Version
        {
            get { return new Version(1, 1); }
        }

        public override bool WantButton
        {
            get
            {
                return true;
            }
        }

        public override string ButtonText
        {
            get
            {
                return "Don't touch me!";
            }
        }

        public override void OnButtonPress()
        {
            SoundPlayer player = new SoundPlayer(@"Plugins/OnyxEggsDetector/sonar.wav");
            player.Play();
        }

        // X and Y are inverted
        private static float x_start = -1002.084f;
        private static float y_start = -5531.25f;
        private static float x_weight = 46.54167f; // 3652.083 / -1002.084
        private static float y_weight = 69.83333f; // 1452.083 / -5531.25
        private readonly WaitTimer clock = new WaitTimer(TimeSpan.FromMilliseconds(1500));

        public override void Pulse() {
            if (!clock.IsFinished) return;

            clock.Reset();

            var eggs = ObjectManager.GetObjectsOfType<WoWGameObject>(true, true).Where(o => o.Entry == 214945);

            float x;
            float y;

            foreach (var egg in eggs)
            {
                if (sentEggs.Contains(egg.Guid)) continue;

                x = (float)Math.Round(100 - ((egg.Y - y_start) / y_weight), 2);
                y = (float)Math.Round(100 - ((egg.X - x_start) / x_weight), 2);

                Logging.Write("Onyx Egg found at [" + x + " " + y + "]");
                Lua.DoString("TomTom:AddWaypoint("+x+", "+y+", \"Yummy egg!\")");
                SoundPlayer player = new SoundPlayer(@"Plugins/OnyxEggsDetector/sonar.wav");
                player.Play();
                sentEggs.Add(egg.Guid);

                // untill proper solution
                Styx.CommonBot.TreeRoot.Stop();
            }
        }
    }
}
